==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/item/equipment/bauble/BenevolentGoddessCharmItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.bauble;

import vazkii.botania.api.mana.ManaItemHandler;
import vazkii.botania.client.render.AccessoryRenderRegistry;
import vazkii.botania.client.render.AccessoryRenderer;
import vazkii.botania.common.handler.EquipmentHandler;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.proxy.Proxy;

import java.util.List;
import net.minecraft.class_1160;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_572;
import net.minecraft.class_809;

public class BenevolentGoddessCharmItem extends BaubleItem {

	public static final int COST = 1000;

	public BenevolentGoddessCharmItem(class_1793 props) {
		super(props);
		Proxy.INSTANCE.runOnClient(() -> () -> AccessoryRenderRegistry.register(this, new Renderer()));
	}

	public static boolean shouldProtectExplosion(class_1937 world, class_243 vec) {
		List<class_1657> players = world.method_18467(class_1657.class, new class_238(vec.field_1352, vec.field_1351, vec.field_1350, vec.field_1352, vec.field_1351, vec.field_1350).method_1014(8));

		for (class_1657 player : players) {
			class_1799 charm = EquipmentHandler.findOrEmpty(BotaniaItems.goddessCharm, player);
			if (!charm.method_7960() && ManaItemHandler.instance().requestManaExact(charm, player, COST, true)) {
				return true;
			}
		}
		return false;
	}

	public static class Renderer implements AccessoryRenderer {
		@Override
		public void doRender(class_572<?> bipedModel, class_1799 stack, class_1309 living, class_4587 ms, class_4597 buffers, int light, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch) {
			bipedModel.field_3398.method_22703(ms);
			ms.method_22904(0.275, -0.4, 0);
			ms.method_22907(class_1160.field_20705.method_23214(-90F));
			ms.method_22905(0.55F, -0.55F, -0.55F);
			class_310.method_1551().method_1480().method_23178(stack, class_809.class_811.field_4315,
					light, class_4608.field_21444, ms, buffers, living.method_5628());
		}
	}

}

==> Botania-1.20.1-449-FABRIC-20250720.151858-38-sources.jar: vazkii/botania/common/item/equipment/bauble/BenevolentGoddessCharmItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.bauble;

import vazkii.botania.api.mana.ManaItemHandler;
import vazkii.botania.client.render.AccessoryRenderRegistry;
import vazkii.botania.client.render.AccessoryRenderer;
import vazkii.botania.common.handler.EquipmentHandler;
import vazkii.botania.common.helper.VecHelper;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.proxy.Proxy;

import java.util.List;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_572;
import net.minecraft.class_811;

public class BenevolentGoddessCharmItem extends BaubleItem {

	public static final int COST = 1000;

	public BenevolentGoddessCharmItem(class_1793 props) {
		super(props);
		Proxy.INSTANCE.runOnClient(() -> () -> AccessoryRenderRegistry.register(this, new Renderer()));
	}

	public static boolean shouldProtectExplosion(class_1937 world, class_243 vec) {
		List<class_1657> players = world.method_18467(class_1657.class, new class_238(vec.field_1352, vec.field_1351, vec.field_1350, vec.field_1352, vec.field_1351, vec.field_1350).method_1014(8));

		for (class_1657 player : players) {
			class_1799 charm = EquipmentHandler.findOrEmpty(BotaniaItems.goddessCharm, player);
			if (!charm.method_7960() && ManaItemHandler.instance().requestManaExact(charm, player, COST, true)) {
				return true;
			}
		}
		return false;
	}

	public static class Renderer implements AccessoryRenderer {
		@Override
		public void doRender(class_572<?> bipedModel, class_1799 stack, class_1309 living, class_4587 ms, class_4597 buffers, int light, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch) {
			bipedModel.field_3398.method_22703(ms);
			ms.method_22904(0.275, -0.4, 0);
			ms.method_22907(VecHelper.rotateY(-90F));
			ms.method_22905(0.55F, -0.55F, -0.55F);
			class_310.method_1551().method_1480().method_23178(stack, class_811.field_4315,
					light, class_4608.field_21444, ms, buffers, living.method_37908(), living.method_5628());
		}
	}

}
